import { ChartAnnotation, ChartDimension, ChartMeasure, ChartSettings, EntityType, Property, QueryReturn } from '@metad/ocap-core';
import { AxisEnum, EChartsContext, EChartsOptions, ICoordinate, IDataset, IVisualMap, SeriesComponentType } from './types';
export declare function cartesian(data: QueryReturn<unknown>, chartAnnotation: ChartAnnotation, entityType: EntityType, settings: ChartSettings, options: EChartsOptions, type: string): EChartsContext;
/**
 * 单个笛卡尔坐标系, 对应一个 grid 内的组件
 *
 * @param data 数据数组
 * @param chartAnnotation 图形注解
 * @param entityType 实体类型
 * @param settings 图形设置
 * @param options 图形属性
 * @returns
 */
export declare function cartesianCoordinate(context: EChartsContext, data: Array<Record<string, unknown>>): ICoordinate;
/**
 * Serialize measure to echarts series component options
 *
 * @param dataset
 * @param seriesComponent
 * @param entityType
 * @param valueAxis
 * @param settings
 * @param options
 * @returns
 */
export declare function serializeSeriesComponent(dataset: IDataset['dataset'], seriesComponent: SeriesComponentType, entityType: EntityType, valueAxis: any, settings: ChartSettings, options: EChartsOptions): {
    series: any;
    visualMaps: any[];
};
export declare function getVisualMapValueAxisIndex(dataset: IDataset['dataset'] | IDataset['dataset'][], seriesComponent: SeriesComponentType, series?: ChartDimension): string | number;
export declare function getLegendColorForVisualMap(colors: any): any;
export declare function getSymbolSizeVisualMap(measure: ChartMeasure, property: Property, dataset: IDataset['dataset'] | IDataset['dataset'][], visualMaps?: IVisualMap[]): any;
export declare function measuresToSeriesComponents(measures: ChartMeasure[], data: any[], entityType: EntityType, settings: ChartSettings): SeriesComponentType[];
export declare function dimensionToSeriesComponent(name: string, dimension: ChartDimension, measures: ChartMeasure[], data: any[], entityType: EntityType, settings: ChartSettings): SeriesComponentType;
/**
 *
 * @param chartAnnotation
 * @param entityType
 * @param items
 * @param chartOptions
 * @param locale
 * @returns
 */
export declare function getCoordinateSystem(context: EChartsContext, items: Array<unknown>, locale: string): {
    categoryAxis: {
        orient: AxisEnum;
        axis: any[];
    };
    valueAxis: {
        orient: AxisEnum;
        axis: any;
    };
};
export declare function getPolarCoordinateSystem(context: EChartsContext, items: Array<unknown>, locale: string): {
    categoryAxis: {
        orient: AxisEnum;
        axis: any[];
    };
    valueAxis: {
        orient: AxisEnum;
        axis: any;
    };
};
