import { mergeOptions, ReferenceLineType, ReferenceLineValueType } from '@metad/ocap-core';
import { formatMeasureNumber } from './common';
import { AxisEnum } from './types';
export function referenceLines(axis1, axis2, options, valueAxis, locale) {
    const formatter = (params) => {
        if (Array.isArray(params)) {
            return params.map(({ value }) => formatMeasureNumber({ measure: axis1, property: null }, value, locale)).join('; ');
        }
        else {
            return formatMeasureNumber({ measure: axis1, property: null }, params.value, locale);
        }
    };
    const markLine = mergeOptions({
        data: [],
        label: {
            formatter
        }
    }, options?.seriesStyle?.markLine);
    const markPoint = mergeOptions({
        data: [],
        label: {
            formatter
        }
    }, options?.seriesStyle?.markPoint);
    axis1?.referenceLines?.forEach((referenceLine) => {
        if (referenceLine.type) {
            const referenceLineData = {
                name: referenceLine.label
                // valueIndex: valueAxis === AxisEnum.x ? 0 : 1,
            };
            if (referenceLine.valueType === ReferenceLineValueType.fixed) {
                referenceLineData[valueAxis] = referenceLine.value;
            }
            else if (referenceLine.valueType === ReferenceLineValueType.dynamic) {
                referenceLineData['type'] = referenceLine.aggregation;
            }
            if (referenceLine.type === ReferenceLineType.markLine) {
                markLine.data.push(referenceLineData);
            }
            else if (referenceLine.type === ReferenceLineType.markPoint) {
                markPoint.data.push(referenceLineData);
            }
        }
    });
    axis2?.referenceLines?.forEach((referenceLine) => {
        if (referenceLine.type) {
            const referenceLineData = {
                name: referenceLine.label,
                valueIndex: valueAxis === AxisEnum.y ? 0 : 1
            };
            if (referenceLine.valueType === ReferenceLineValueType.fixed) {
                referenceLineData[valueAxis] = referenceLine.value;
            }
            else if (referenceLine.valueType === ReferenceLineValueType.dynamic) {
                referenceLineData['type'] = referenceLine.aggregation;
            }
            if (referenceLine.type === ReferenceLineType.markLine) {
                markLine.data.push(referenceLineData);
            }
            else if (referenceLine.type === ReferenceLineType.markPoint) {
                markPoint.data.push(referenceLineData);
            }
        }
    });
    return {
        markLine,
        markPoint
    };
}
//# sourceMappingURL=series.js.map