import { assignDeepOmitBlank, ChartDimensionRoleType, getChartCategory, getChartSeries, getEntityHierarchy, getEntityLevel, getEntityProperty, getPropertyCaption, omitBlank } from '@metad/ocap-core';
import format from 'date-fns/format';
import parse from 'date-fns/parse';
import { cloneDeep } from 'lodash-es';
import { formatMeasureNumber } from './common';
import { coordinates, gatherCoordinates } from './coordinates';
export function themeRiver(data, chartAnnotation, entityType, settings, options) {
    // 智能补全信息
    const index = chartAnnotation.dimensions.findIndex((item) => item.role === ChartDimensionRoleType.Category2);
    if (index === -1) {
        chartAnnotation = cloneDeep(chartAnnotation);
        const dimension = chartAnnotation.dimensions.slice(1).find((item) => !item.role);
        if (dimension) {
            dimension.role = ChartDimensionRoleType.Category2;
        }
    }
    const context = {
        data,
        entityType,
        settings,
        options,
        chartAnnotation
    };
    const coordinateDatas = coordinates(context, 'grid', themeRiverCoordinate);
    return {
        ...context,
        echartsOptions: gatherCoordinates(coordinateDatas, 'themeRiver', options),
        onClick: (event) => {
            console.log(event, chartAnnotation);
            const dimension = getChartSeries(chartAnnotation);
            const slicer = {
                dimension,
                members: [
                    {
                        value: event.value[3],
                        label: event.value[2]
                    }
                ]
            };
            return {
                ...event,
                event: event.event?.event,
                filter: slicer
            };
        }
    };
}
/**
 * 未来支持:
 *  1. 基于维度成员的主题河
 *  2. 基于不同度量的主题河
 *
 * @param data
 * @param chartAnnotation
 * @param entityType
 * @param settings
 * @param options
 * @returns
 */
export function themeRiverCoordinate(context, data) {
    const { chartAnnotation, entityType, settings, options } = context;
    const category = getChartCategory(chartAnnotation);
    const categoryProperty = getEntityHierarchy(entityType, category);
    const category2 = getChartSeries(chartAnnotation);
    if (!category2) {
        throw new Error(`Can't found dimension for series`);
    }
    const category2Hierarchy = getEntityHierarchy(entityType, category2);
    const category2Caption = getPropertyCaption(category2Hierarchy);
    const measure = chartAnnotation.measures[0];
    const categoryLevelProperty = getEntityLevel(entityType, category);
    const formatter = categoryLevelProperty.semantics?.formatter || 'yyyyMMdd';
    const coordinateOptions = {
        type: 'SingleAxis',
        name: '',
        datasets: [
            {
                series: [
                    assignDeepOmitBlank({
                        data: data.map((item) => [
                            format(parse(item[categoryProperty.name], formatter, new Date()), 'yyyy/MM/dd'),
                            item[measure.measure],
                            item[category2Caption],
                            item[category2Hierarchy.name]
                        ])
                    }, options?.seriesStyle, 2)
                ]
            }
        ],
        grid: assignDeepOmitBlank({}, options?.grid),
        singleAxis: [
            assignDeepOmitBlank({
                type: 'time'
            }, options?.singleAxis)
        ],
        visualMap: [],
        tooltip: [],
        legend: []
    };
    if (options?.legend) {
        coordinateOptions.legend.push(omitBlank(options.legend));
    }
    if (options?.tooltip) {
        coordinateOptions.tooltip.push(assignDeepOmitBlank({
            valueFormatter: (value) => formatMeasureNumber({ measure, property: getEntityProperty(entityType, measure.measure) }, value, settings?.locale)
        }, options.tooltip));
    }
    return coordinateOptions;
}
//# sourceMappingURL=themeRiver.js.map